abacusai.item_statistics — AbacusAI documentation

# `abacusai.item_statistics`

## Module Contents

### Classes

`ItemStatistics` | ItemStatistics representation.

class abacusai.item_statistics.ItemStatistics(client, missingPercent=None, count=None, median=None, mean=None, p10=None, p90=None, stddev=None, min=None, max=None, lowerBound=None, upperBound=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  ItemStatistics representation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - missingPercent (float) – percentage of missing values in data

    - count (int) – count of data

    - median (float) – median of the data

    - mean (float) – mean value of the data

    - p10 (float) – 10th percentile of the data

    - p90 (float) – 90th_percentile of the data

    - stddev (float) – standard deviation of the data

    - min (int) – min value in the data

    - max (int) – max value in the data

    - lowerBound (float) – lower bound threshold of the data

    - upperBound (float) – upper bound threshold of the data

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict